@@ -1,5 +1,4 @@
 import json
-import logging
 import os
 import sys
 from datetime import datetime, timedelta, timezone
@@ -22,7 +21,11 @@ from deck_chores.indexes import (
     service_locks_by_container_id,
 )
 from deck_chores.parsers import job_config_validator, parse_labels
-from deck_chores.utils import DEBUG, log, setup_stderr_logging, stdout_log_handler
+from deck_chores.utils import (
+    DEBUG,
+    log,
+    configure_logging,
+)
 
 
 ####
@@ -277,8 +280,17 @@ def shutdown() -> None:  # pragma: nocover
 
 
 def main() -> None:  # pragma: nocover
+
     if DEBUG and not __debug__:
-        log.debug("Replacing process with Python's optimizations off.")
+        log.info("Replacing process with Python's optimizations off.")
+        sys.stdout.flush()
+        os.execlpe("deck-chores", "deck-chores", {**os.environ, "PYTHONOPTIMIZE": ""})
+
+    if not DEBUG and __debug__:
+        log.info(
+            "Replacing process with Python's optimizations set to level one in order "
+            "to evaluate assert statements."
+        )
         sys.stdout.flush()
         os.execlpe("deck-chores", "deck-chores", {**os.environ, "PYTHONOPTIMIZE": "1"})
 
@@ -290,11 +302,7 @@ def main() -> None:  # pragma: nocover
 
     try:
         generate_config()
-
-        log_formatter = logging.Formatter(cfg.logformat, style='{')
-        stdout_log_handler.setFormatter(log_formatter)
-        setup_stderr_logging(log_formatter, cfg.stderr_level)
-
+        configure_logging(cfg)
         log.debug(f'Config: {cfg.__dict__}')
 
         if there_is_another_deck_chores_container():
